@@ -15,6 +15,7 @@
 import json
 
 from functionaltests.api import base
+from tempest import exceptions as tempest_exceptions
 
 sample_data = {"name": "test_language_pack",
                "description": "A test to create language_pack",
@@ -99,6 +100,10 @@ class TestLanguagePackController(base.TestCase):
         self._assert_output_expected(json_data, sample_data)
         self._delete_language_pack(json_data['uuid'])
 
+    def test_language_packs_create_none(self):
+        self.assertRaises(tempest_exceptions.BadRequest,
+                          self.client.post, 'v1/language_packs', "{}")
+
     def test_language_packs_get(self):
         uuid = self._create_language_pack()
         resp, body = self.client.get('v1/language_packs/%s' % uuid)
@@ -107,11 +112,15 @@ class TestLanguagePackController(base.TestCase):
         self._assert_output_expected(json_data, sample_data)
         self._delete_language_pack(uuid)
 
+    def test_language_packs_get_not_found(self):
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.get, 'v1/language_packs/not_found')
+
     def test_language_packs_put(self):
         self.skipTest("Tags update not implemented yet in python-glanceclient")
         # See http://goo.gl/vg9h6G
         uuid = self._create_language_pack()
-        updated_data = {"name": "test_language_pack updated",
+        updated_data = {"name": "test_language_pack_updated",
                         "description": "A test to create language_pack update",
                         "language_pack_type": "python",
                         "language_implementation": "py",
@@ -135,8 +144,38 @@ class TestLanguagePackController(base.TestCase):
         self._assert_output_expected(json_data, updated_data)
         self._delete_language_pack(uuid)
 
+    def test_language_packs_put_not_found(self):
+        updated_data = {"name": "test_language_pack_updated",
+                        "description": "A test to create language_pack update",
+                        "language_pack_type": "python",
+                        "language_implementation": "py",
+                        "runtime_versions": ["1.3", "1.5"],
+                        "compiler_versions": ["1.4", "1.7"],
+                        "build_tool_chain": [{
+                            "type": "maven",
+                            "version": "3.1"
+                        }, {
+                            "type": "gradle",
+                            "version": "0.9"
+                        }],
+                        "os_platform": {"OS": "Fedora", "version": "17"},
+                        "attributes": {"key11": "value11", "key2": "value22"},
+                        "type": "language_pack"}
+        updated_json = json.dumps(updated_data)
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.put, 'v1/language_packs/not_found',
+                          updated_json)
+
+    def test_language_packs_put_none(self):
+        self.assertRaises(tempest_exceptions.BadRequest,
+                          self.client.put, 'v1/language_packs/any', "{}")
+
     def test_language_packs_delete(self):
         uuid = self._create_language_pack()
         resp, body = self.client.delete('v1/language_packs/%s' % uuid)
         self.assertEqual(resp.status, 204)
         self.assertEqual(body, '')
+
+    def test_language_packs_delete_not_found(self):
+        self.assertRaises(tempest_exceptions.NotFound,
+                          self.client.delete, 'v1/language_packs/not_found')
