@@ -14,6 +14,8 @@
 
 # This script is executed inside post_test_hook function in devstack gate.
 
+# Install packages from test-requirements.txt
+sudo pip install -r /opt/stack/new/solum/test-requirements.txt
 
 cd /opt/stack/new/solum/functionaltests
-sudo ./run_tests_split.sh
+sudo ./run_tests.sh
