@@ -12,7 +12,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-# This script is executed inside pre_test_hook function in devstack gate.
+# This script is executed inside pre_test_hook function in desvstack gate.
 
+# Install solum devstack integration
+SOLUM_BASE=/opt/stack/new/solum/contrib/devstack
 DEVSTACK_BASE=/opt/stack/new/devstack
-DEVSTACK_GATE=/opt/stack/new/devstack-gate
+cp $SOLUM_BASE/lib/* $DEVSTACK_BASE/lib
+cp $SOLUM_BASE/extras.d/* $DEVSTACK_BASE/extras.d
