@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #
 # Copyright 2013 - Noorul Islam K M
 #
@@ -14,16 +15,13 @@
 # under the License.
 
 from solum.api import auth
-from solum.api import release
 
 # Pecan Application Configurations
 app = {
     'root': 'solum.api.controllers.root.RootController',
     'modules': ['solum.api'],
     'debug': False,
-    'hooks': [auth.AuthInformationHook(),
-              release.ReleaseReporter(),
-              ]
+    'hooks': [auth.AuthInformationHook()]
 }
 
 # Custom Configurations must be in Python dictionary format::
