@@ -13,6 +13,7 @@
 # under the License.
 
 import uuid
+
 import wsme
 from wsme.rest import json as wjson
 from wsme import types as wtypes
@@ -117,16 +118,10 @@ class Plan(api_types.Base):
 
     @classmethod
     def from_db_model(cls, m, host_url):
-        json = m.as_dict()
-        json['type'] = m.__tablename__
-        json['uri'] = '%s/v1/%s/%s' % (host_url, m.__resource__, m.uuid)
-        if m.raw_content is not None:
-            json.update(m.raw_content)
-        del json['id']
-        return cls(**(json))
+        return cls(**(m.raw_content))
 
     def as_dict(self, db_model):
-        base = super(Plan, self).as_dict(db_model)
+        base = super(Plan, self).as_dict_from_keys(['name', 'description'])
         if self.artifacts is not wsme.Unset:
             base.update({'artifacts': [wjson.tojson(Artifact, art)
                                        for art in self.artifacts]})
