@@ -18,23 +18,20 @@ import wsme
 import wsmeext.pecan as wsme_pecan
 
 from solum.api.controllers.v1.datamodel import pipeline
-from solum.api.controllers.v1 import execution
 from solum.api.handlers import pipeline_handler
 from solum.common import exception
-from solum.i18n import _
 from solum import objects
+from solum.openstack.common.gettextutils import _
 
 
 class PipelineController(rest.RestController):
     """Manages operations on a single pipeline."""
 
-    executions = execution.ExecutionsController()
-
     def __init__(self, pipeline_id):
         super(PipelineController, self).__init__()
         self._id = pipeline_id
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(pipeline.Pipeline)
     def get(self):
         """Return this pipeline."""
@@ -43,7 +40,7 @@ class PipelineController(rest.RestController):
         return pipeline.Pipeline.from_db_model(handler.get(self._id),
                                                pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(pipeline.Pipeline, body=pipeline.Pipeline)
     def put(self, data):
         """Modify this pipeline."""
@@ -53,7 +50,7 @@ class PipelineController(rest.RestController):
                              data.as_dict(objects.registry.Pipeline))
         return pipeline.Pipeline.from_db_model(res, pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(status_code=204)
     def delete(self):
         """Delete this pipeline."""
@@ -66,12 +63,12 @@ class PipelinesController(rest.RestController):
     """Manages operations on the pipeline collection."""
 
     @pecan.expose()
-    def _lookup(self, pipeline_id, *remainder):
+    def _lookup(self, _id, *remainder):
         if remainder and not remainder[-1]:
             remainder = remainder[:-1]
-        return PipelineController(pipeline_id), remainder
+        return PipelineController(_id), remainder
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(pipeline.Pipeline,
                          body=pipeline.Pipeline,
                          status_code=201)
@@ -100,7 +97,7 @@ class PipelinesController(rest.RestController):
         return pipeline.Pipeline.from_db_model(
             handler.create(js_data), pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose([pipeline.Pipeline])
     def get_all(self):
         """Return all pipelines."""
