@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_utils import uuidutils
+import uuid
 
 from solum.api.handlers import handler
 from solum import objects
@@ -25,9 +25,10 @@ class ExtensionHandler(handler.Handler):
 
     def update(self, id, data):
         """Modify the extension."""
-        updated = objects.registry.Extension.update_and_save(self.context,
-                                                             id, data)
-        return updated
+        db_obj = objects.registry.Extension.get_by_uuid(self.context, id)
+        db_obj.update(data)
+        db_obj.save(self.context)
+        return db_obj
 
     def delete(self, id):
         """Delete the extension."""
@@ -38,7 +39,7 @@ class ExtensionHandler(handler.Handler):
         """Create a new extension."""
         db_obj = objects.registry.Extension()
         db_obj.update(data)
-        db_obj.uuid = uuidutils.generate_uuid()
+        db_obj.uuid = str(uuid.uuid4())
         db_obj.user_id = self.context.user
         db_obj.project_id = self.context.tenant
         db_obj.create(self.context)
