@@ -14,9 +14,8 @@
 
 """Solum specific config handling."""
 
-from oslo_config import cfg
+from oslo.config import cfg
 
-from solum.common import config as common_config
 from solum import version
 
 
@@ -25,4 +24,3 @@ def parse_args(argv, default_config_files=None):
              project='solum',
              version=version.version_string(),
              default_config_files=default_config_files)
-    common_config.set_config_defaults()
