@@ -15,15 +15,15 @@
 """Config options for Solum Deployer service."""
 
 
-from oslo_config import cfg
+from oslo.config import cfg
 
 SERVICE_OPTS = [
     cfg.StrOpt('topic',
                default='solum-deployer',
                help='The queue to add deployer tasks to'),
-    cfg.HostAddressOpt('host',
-                       default='localhost',
-                       help='The location of the deployer rpc queue'),
+    cfg.StrOpt('host',
+               default='localhost',
+               help='The location of the deployer rpc queue'),
     cfg.StrOpt('handler',
                default='heat',
                help='The deployer endpoint to deploy'),
@@ -32,11 +32,5 @@ SERVICE_OPTS = [
 opt_group = cfg.OptGroup(
     name='deployer',
     title='Options for the solum-deployer service')
-
-
-def list_opts():
-    yield opt_group, SERVICE_OPTS
-
-
 cfg.CONF.register_group(opt_group)
 cfg.CONF.register_opts(SERVICE_OPTS, opt_group)
