@@ -33,6 +33,7 @@ class Assembly(sql.Base, abstract.Assembly):
     project_id = sa.Column(sa.String(36))
     user_id = sa.Column(sa.String(36))
     trigger_id = sa.Column(sa.String(36))
+    trust_id = sa.Column(sa.String(255))
     name = sa.Column(sa.String(100))
     description = sa.Column(sa.String(255))
     tags = sa.Column(sa.Text)
@@ -72,6 +73,14 @@ class Assembly(sql.Base, abstract.Assembly):
         return session.query(component.Component).filter_by(
             assembly_id=self.id).all()
 
+    def destroy(self, context):
+        session = sql.Base.get_session()
+        with session.begin():
+            session.query(component.Component).filter_by(
+                assembly_id=self.id).delete()
+            session.query(self.__class__).filter_by(
+                id=self.id).delete()
+
 
 class AssemblyList(abstract.AssemblyList):
     """Represent a list of assemblies in sqlalchemy."""
