@@ -32,7 +32,12 @@ class Plan(sql.Base, abstract.Plan):
     user_id = sqlalchemy.Column(sqlalchemy.String(36))
     name = sqlalchemy.Column(sqlalchemy.String(255))
     description = sqlalchemy.Column(sqlalchemy.String(255))
-    raw_content = sqlalchemy.Column(sql.JSONEncodedDict(2048))
+    raw_content = sqlalchemy.Column(sql.YAMLEncodedDict(2048))
+
+    def refined_content(self):
+        if self.raw_content and self.uuid:
+            self.raw_content['uuid'] = self.uuid
+        return self.raw_content
 
 
 class PlanList(abstract.PlanList):
