@@ -37,8 +37,8 @@ class TestAssemblyHandler(base.BaseTestCase):
         handler = assembly_handler.AssemblyHandler(self.ctx)
         res = handler.get('test_id')
         self.assertIsNotNone(res)
-        mock_registry.Assembly.get_by_uuid.\
-            assert_called_once_with(self.ctx, 'test_id')
+        get_by_uuid = mock_registry.Assembly.get_by_uuid
+        get_by_uuid.assert_called_once_with(self.ctx, 'test_id')
 
     def test_assembly_get_all(self, mock_registry):
         mock_registry.AssemblyList.get_all.return_value = {}
