@@ -172,12 +172,33 @@ class FakeAssembly(mock.Mock):
                     status=self.status)
 
 
+class FakePipeline(mock.Mock):
+    def __init__(self, **kwargs):
+        super(FakePipeline, self).__init__(**kwargs)
+        self.__tablename__ = 'pipeline'
+        self.__resource__ = 'pipelines'
+        self.user_id = 'fake user id'
+        self.project_id = 'fake project id'
+        self.plan_uuid = 'fake plan uuid'
+        self.uuid = 'test_uuid'
+        self.id = 8
+        self.name = 'faker'
+        self.trust_id = 'trust_worthy'
+
+    def as_dict(self):
+        return dict(user_id=self.user_id,
+                    project_id=self.project_id,
+                    uuid=self.uuid,
+                    id=self.id,
+                    name=self.name)
+
+
 class FakePlan(mock.Mock):
     def __init__(self, **kwargs):
         super(FakePlan, self).__init__(**kwargs)
         self.__tablename__ = 'plan'
         self.__resource__ = 'plans'
-        self.raw_content = {'artifacts': []}
+        self.raw_content = {'name': 'faker', 'artifacts': []}
         self.user_id = 'fake user id'
         self.project_id = 'fake project id'
         self.uuid = 'test_uuid'
@@ -192,6 +213,11 @@ class FakePlan(mock.Mock):
                     id=self.id,
                     name=self.name)
 
+    def refined_content(self):
+        if self.raw_content and self.uuid:
+            self.raw_content['uuid'] = self.uuid
+        return self.raw_content
+
 
 class FakeImage(mock.Mock):
     def __init__(self, **kwargs):
