@@ -13,7 +13,6 @@
 # limitations under the License.
 
 from solum.objects import registry
-from solum.objects.sqlalchemy import execution
 from solum.objects.sqlalchemy import pipeline
 from solum.tests import base
 from solum.tests import utils
@@ -25,7 +24,7 @@ class TestPipeline(base.BaseTestCase):
         self.db = self.useFixture(utils.Database())
         self.ctx = utils.dummy_context()
 
-        self.data = [{'project_id': self.ctx.tenant,
+        self.data = [{'project_id': 'project_id_blah',
                       'uuid': 'ce43e347f0b0422825245b3e5f140a81cef6e65b',
                       'user_id': 'fred',
                       'name': 'pipeline1',
@@ -53,24 +52,3 @@ class TestPipeline(base.BaseTestCase):
             'trigger_id'])
         for key, value in self.data[0].items():
             self.assertEqual(value, getattr(ta, key))
-
-    def test_last_execution(self):
-        ta = pipeline.Pipeline().get_by_id(self.ctx, self.data[0]['id'])
-        # add executions
-        ex1 = execution.Execution()
-        ex1.uuid = 'first'
-        ex1.pipeline_id = ta.id
-        ex1.create(self.ctx)
-
-        ex2 = execution.Execution()
-        ex2.uuid = 'second'
-        ex2.pipeline_id = ta.id
-        ex2.create(self.ctx)
-
-        extest = ta.last_execution()
-        self.assertEqual('second', extest.uuid)
-
-    def test_last_execution_none(self):
-        ta = pipeline.Pipeline().get_by_id(self.ctx, self.data[0]['id'])
-        extest = ta.last_execution()
-        self.assertIsNone(extest)
